bottle_compression_zlib {#master}
-------------------------

## Important Changes

### portmonitors

* added new portmonitor `bottle_compression_zlib` to compress bottles (or yarp data types which can be converted to bottle)


